==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/CIAO/CCF/CCF/IDL2/SemanticGraph/ValueTypeMember.hpp <==
// file      : CCF/IDL2/SemanticGraph/ValueTypeMember.hpp
// author    : Boris Kolpackov <boris@dre.vanderbilt.edu>
// cvs-id    : ValueTypeMember.hpp,v 1.1 2005/03/18 18:09:15 boris Exp

#ifndef CCF_IDL2_SEMANTIC_GRAPH_VALUE_TYPE_MEMBER_HPP
#define CCF_IDL2_SEMANTIC_GRAPH_VALUE_TYPE_MEMBER_HPP

#include "CCF/IDL2/SemanticGraph/Elements.hpp"

namespace CCF
{
  namespace IDL2
  {
    namespace SemanticGraph
    {

      //
      //
      //
      class ValueTypeMember : public virtual Nameable,
                              public virtual Instance
      {
      public:
        struct Access
        {
          enum Value
          {
            public_,
            private_
          };
        };

        virtual Access::Value
        access () const = 0;

      public:
        static Introspection::TypeInfo const&
        static_type_info ();

      protected:
        ValueTypeMember ()
        {
          type_info (static_type_info ());
        }
      };


      //
      //
      //
      class ValueTypePrivateMember : public virtual ValueTypeMember
      {
      public:
        virtual Access::Value
        access () const
        {
          return Access::private_;
        }

      public:
        static Introspection::TypeInfo const&
        static_type_info ();

      protected:
        friend class Graph<Node, Edge>;

        ValueTypePrivateMember ()
        {
          type_info (static_type_info ());
        }
      };


      //
      //
      //
      class ValueTypePublicMember : public virtual ValueTypeMember
      {
      public:
        virtual Access::Value
        access () const
        {
          return Access::public_;
        }

      public:
        static Introspection::TypeInfo const&
        static_type_info ();

      protected:
        friend class Graph<Node, Edge>;

        ValueTypePublicMember ()
        {
          type_info (static_type_info ());
        }
      };
    }
  }
}

#endif  // CCF_IDL2_SEMANTIC_GRAPH_VALUE_TYPE_MEMBER_HPP

==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/CIAO/CCF/CCF/IDL2/SemanticGraph/ValueTypeMember.hpp <==
// file      : CCF/IDL2/SemanticGraph/ValueTypeMember.hpp
// author    : Boris Kolpackov <boris@dre.vanderbilt.edu>
// cvs-id    : $Id: ValueTypeMember.hpp 74499 2006-09-22 10:02:37Z boris $

#ifndef CCF_IDL2_SEMANTIC_GRAPH_VALUE_TYPE_MEMBER_HPP
#define CCF_IDL2_SEMANTIC_GRAPH_VALUE_TYPE_MEMBER_HPP

#include "CCF/IDL2/SemanticGraph/Elements.hpp"

namespace CCF
{
  namespace IDL2
  {
    namespace SemanticGraph
    {

      //
      //
      //
      class ValueTypeMember : public virtual Nameable,
                              public virtual Instance
      {
      public:
        struct Access
        {
          enum Value
          {
            public_,
            private_
          };
        };

        virtual Access::Value
        access () const = 0;

      public:
        static Introspection::TypeInfo const&
        static_type_info ();

      protected:
        ValueTypeMember () // For virtual inheritance only.
        {
          type_info (static_type_info ());
        }

        virtual
        ~ValueTypeMember () = 0;
      };


      //
      //
      //
      class ValueTypePrivateMember : public virtual ValueTypeMember
      {
      public:
        virtual Access::Value
        access () const
        {
          return Access::private_;
        }

      public:
        static Introspection::TypeInfo const&
        static_type_info ();

      protected:
        friend class Graph<Node, Edge>;

        ValueTypePrivateMember (Path const& path, unsigned long line)
            : Node (path, line)
        {
          type_info (static_type_info ());
        }
      };


      //
      //
      //
      class ValueTypePublicMember : public virtual ValueTypeMember
      {
      public:
        virtual Access::Value
        access () const
        {
          return Access::public_;
        }

      public:
        static Introspection::TypeInfo const&
        static_type_info ();

      protected:
        friend class Graph<Node, Edge>;

        ValueTypePublicMember (Path const& path, unsigned long line)
            : Node (path, line)
        {
          type_info (static_type_info ());
        }
      };
    }
  }
}

#endif  // CCF_IDL2_SEMANTIC_GRAPH_VALUE_TYPE_MEMBER_HPP
